@@ -17,7 +17,7 @@ def test_str_py3():
 
     keys = ['first', 'second', 'third', 'fourth']
 
-    testdata = [dict((key, gen_id()) for key in keys) for _ in range(50)]
+    testdata = [{key: gen_id() for key in keys} for _ in range(50)]
 
     schema = {
         "fields": [{'name': key, 'type': 'string'} for key in keys],
@@ -30,7 +30,7 @@ def test_str_py3():
     fastavro.writer(buf, schema, testdata)
 
     buf.seek(0, SEEK_SET)
-    for i, rec in enumerate(fastavro.iter_avro(buf), 1):
+    for i, rec in enumerate(fastavro.reader(buf), 1):
         pass
 
     size = len(testdata)
